==> open-parties-and-claims-common-1.20.4-0.25.10-sources.jar: xaero/pac/common/mixin/MixinExperienceOrb.java <==
/*
 * Open Parties and Claims - adds chunk claims and player parties to Minecraft
 * Copyright (C) 2022-2026, Xaero <xaero1996@gmail.com> and contributors
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of version 3 of the GNU Lesser General Public License
 * (LGPL-3.0-only) as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received copies of the GNU Lesser General Public License
 * and the GNU General Public License along with this program.
 * If not, see <https://www.gnu.org/licenses/>.
 */

package xaero.pac.common.mixin;

import net.minecraft.world.entity.ExperienceOrb;
import net.minecraft.world.entity.player.Player;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;
import xaero.pac.common.server.core.ServerCore;

@Mixin(ExperienceOrb.class)
public class MixinExperienceOrb {

	@Shadow
	private Player followingPlayer;

	@Inject(method = "playerTouch", at = @At("HEAD"), cancellable = true)
	public void onPlayerTouch(Player player, CallbackInfo ci){
		if(ServerCore.onExperiencePickup(player, (ExperienceOrb)(Object)this) == null)
			ci.cancel();
	}

	@Inject(method = "scanForEntities", at = @At(value = "INVOKE_ASSIGN", shift = At.Shift.AFTER, target = "Lnet/minecraft/world/level/Level;getNearestPlayer(Lnet/minecraft/world/entity/Entity;D)Lnet/minecraft/world/entity/player/Player;"), cancellable = true)
	public void onScanForEntities(CallbackInfo ci){
		followingPlayer = ServerCore.onExperiencePickup(followingPlayer, (ExperienceOrb)(Object)this);
	}

	@Inject(method = "merge(Lnet/minecraft/world/entity/ExperienceOrb;)V", at = @At("HEAD"), cancellable = true)
	private void onMerge(ExperienceOrb from, CallbackInfo ci){
		if(ServerCore.onExperienceMerge(from, (ExperienceOrb)(Object)this))
			ci.cancel();
	}

}

==> open-parties-and-claims-common-1.21.8-0.25.10-sources.jar: xaero/pac/common/mixin/MixinExperienceOrb.java <==
/*
 * Open Parties and Claims - adds chunk claims and player parties to Minecraft
 * Copyright (C) 2022-2026, Xaero <xaero1996@gmail.com> and contributors
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of version 3 of the GNU Lesser General Public License
 * (LGPL-3.0-only) as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received copies of the GNU Lesser General Public License
 * and the GNU General Public License along with this program.
 * If not, see <https://www.gnu.org/licenses/>.
 */

package xaero.pac.common.mixin;

import net.minecraft.world.entity.ExperienceOrb;
import net.minecraft.world.entity.player.Player;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.ModifyVariable;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;
import xaero.pac.common.server.core.ServerCore;

@Mixin(ExperienceOrb.class)
public class MixinExperienceOrb {

	@Inject(method = "playerTouch", at = @At("HEAD"), cancellable = true)
	public void onPlayerTouch(Player player, CallbackInfo ci){
		if(ServerCore.onExperiencePickup(player, (ExperienceOrb)(Object)this) == null)
			ci.cancel();
	}

	@Inject(method = "merge(Lnet/minecraft/world/entity/ExperienceOrb;)V", at = @At("HEAD"), cancellable = true)
	private void onMerge(ExperienceOrb from, CallbackInfo ci){
		if(ServerCore.onExperienceMerge(from, (ExperienceOrb)(Object)this))
			ci.cancel();
	}

}
